@@ -27,6 +27,8 @@
 
 #include <QDebug>
 #include <QMediaDevices>
+#include <QMediaCaptureSession>
+#include <QCamera>
 #include <QCameraDevice>
 #include <QCameraFormat>
 #include <QRadioButton>
@@ -41,6 +43,9 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QRectF>
+#include <QSpacerItem>
+#include <QVideoFrameFormat>
+#include <QVideoSink>
 
 QvkCameraSingle::QvkCameraSingle( Ui_formMainWindow *ui_surface, QCameraDevice m_cameraDevice )
 {
@@ -48,16 +53,17 @@ QvkCameraSingle::QvkCameraSingle( Ui_formMainWindow *ui_surface, QCameraDevice m
     cameraDevice = m_cameraDevice;
     qDebug().noquote() << global::nameOutput << "[Camera] Added:" << cameraDevice.description() << "Device:" << cameraDevice.id();
 
-    QList<QVBoxLayout *> listQVBoxLayout = ui->centralWidget->findChildren<QVBoxLayout *>( "layoutAllCameras" );
-
     QHBoxLayout *layoutCamera = new QHBoxLayout;
     layoutCamera->setObjectName( "layoutCamera-" + QString::number( 0 ) );
-    listQVBoxLayout.at(0)->addLayout( layoutCamera );
+    QList<QVBoxLayout *> listQVBoxLayout = ui->centralWidget->findChildren<QVBoxLayout *>( "layoutAllCameras" );
+    QVBoxLayout *layout = listQVBoxLayout.at(0);
+    layout->addLayout( layoutCamera );
 
     QList<QRadioButton *> listRadioButton = ui->centralWidget->findChildren<QRadioButton *>();
     int counter = 0;
     for ( int i = 0; i < listRadioButton.count(); i++ ) {
-        if ( listRadioButton.at(i)->objectName().contains( "radioButtonCamera-" ) ) {
+        QRadioButton *radioButton = listRadioButton.at(i);
+        if ( radioButton->objectName().contains( "radioButtonCamera-" ) ) {
             counter++;
         }
     }
@@ -92,29 +98,40 @@ QvkCameraSingle::QvkCameraSingle( Ui_formMainWindow *ui_surface, QCameraDevice m
     layoutCamera->addWidget( radioButtonCamera );
     radioButtonCamera->setObjectName( "radioButtonCamera-" + QString::number( counter ) );
     radioButtonCamera->setAutoExclusive( true );
-    connect( radioButtonCamera, SIGNAL( clicked( bool ) ), this, SLOT( slot_radioButtonCurrentCameraClicked( bool ) ) );
+    connect( radioButtonCamera, SIGNAL( clicked(bool) ), this, SLOT( slot_radioButtonCurrentCameraClicked(bool) ) );
 
     checkBoxCameraOnOff = new QCheckBox;
     layoutCamera->addWidget( checkBoxCameraOnOff );
     checkBoxCameraOnOff->setText( cameraDevice.description() );
     checkBoxCameraOnOff->setAccessibleName( cameraDevice.id() );
     checkBoxCameraOnOff->setObjectName( "checkBoxCameraOnOff-" + QString::number( counter ) );
-    connect( checkBoxCameraOnOff, SIGNAL( clicked( bool ) ), this, SLOT( slot_checkBoxCameraOnOff( bool ) ) );
+    connect( checkBoxCameraOnOff, SIGNAL( clicked(bool) ), this, SLOT( slot_checkBoxCameraOnOff(bool) ) );
     layoutCamera->setStretchFactor( checkBoxCameraOnOff, 2 );
 
     comboBoxCameraVideoFormat = new QComboBox;
     comboBoxCameraVideoFormat->setMinimumWidth( 100 );
     comboBoxCameraVideoFormat->setObjectName( "comboBoxCameraVideoFormat-" + QString::number( counter ) );
-    connect( comboBoxCameraVideoFormat, SIGNAL( currentIndexChanged( int ) ), this, SLOT( slot_comboboxCameraResolutionsInsertValues( int ) ) ); // Wird im Slot dosconnected
-    connect( comboBoxCameraVideoFormat, SIGNAL( currentIndexChanged( int ) ), this, SLOT( slot_comboboxCameraFormatCurrentIndexChanged( int ) ) );
+    connect( comboBoxCameraVideoFormat, SIGNAL( currentIndexChanged(int) ), this, SLOT( slot_comboboxCameraResolutionsInsertValues(int) ) ); // Wird im Slot dosconnected
+    connect( comboBoxCameraVideoFormat, SIGNAL( currentIndexChanged(int) ), this, SLOT( slot_comboboxCameraFormatCurrentIndexChanged(int) ) );
     layoutCamera->addWidget( comboBoxCameraVideoFormat );
 
     comboBoxCameraResolution = new QComboBox;
     comboBoxCameraResolution->setMinimumWidth( 100 );
     comboBoxCameraResolution->setObjectName( "comboBoxCameraResolution-" + QString::number( counter ) );
-    connect( comboBoxCameraResolution,  SIGNAL( currentIndexChanged( int ) ), this, SLOT( slot_comboboxCameraResolutionsCurrentIndexChanged( int ) ) );
+    connect( comboBoxCameraResolution,  SIGNAL( currentIndexChanged(int) ), this, SLOT( slot_comboboxCameraResolutionsCurrentIndexChanged(int) ) );
     layoutCamera->addWidget( comboBoxCameraResolution );
 
+    pushButtonShortcut = new QPushButton;
+    pushButtonShortcut->setObjectName( "pushButtonCameraShortcut-" + QString::number( counter ) );
+    pushButtonShortcut->setIcon( QIcon( ":/pictures/screencast/accept.png" ) );
+    pushButtonShortcut->setCheckable( true );
+    pushButtonShortcut->setChecked( true );
+    pushButtonShortcut->setMinimumWidth( 110 );
+    pushButtonShortcut->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred ); // Nur das Vertikale funktioniert
+    pushButtonShortcut->updateGeometry();
+    connect( pushButtonShortcut, SIGNAL( clicked(bool) ), this, SLOT( slot_pushButtonShortcut(bool) ) );
+    layoutCamera->addWidget( pushButtonShortcut );
+
     toolButton_camera_view_rectangle = new QToolButton;
     toolButton_camera_view_rectangle->setObjectName( "toolButton_camera_view_rectangle-" + QString::number( counter ) );
     toolButton_camera_view_rectangle->setCheckable( true );
@@ -123,7 +140,7 @@ QvkCameraSingle::QvkCameraSingle( Ui_formMainWindow *ui_surface, QCameraDevice m
     toolButton_camera_view_rectangle->setAutoRaise( true );
     toolButton_camera_view_rectangle->setIconSize( QSize( 34, 34 ) );
     toolButton_camera_view_rectangle->setIcon( QIcon( ":/pictures/camera/window-rectangle-off.png" ) );
-    connect( toolButton_camera_view_rectangle, SIGNAL( clicked( bool ) ), this, SLOT( slot_toolButtonRectangleClicked( bool ) ) );
+    connect( toolButton_camera_view_rectangle, SIGNAL( clicked(bool) ), this, SLOT( slot_toolButtonRectangleClicked(bool) ) );
 
     toolButton_camera_view_ellipse = new QToolButton;
     toolButton_camera_view_ellipse->setObjectName( "toolButton_camera_view_ellipse-" + QString::number( counter ) );
@@ -132,7 +149,7 @@ QvkCameraSingle::QvkCameraSingle( Ui_formMainWindow *ui_surface, QCameraDevice m
     toolButton_camera_view_ellipse->setAutoRaise( true );
     toolButton_camera_view_ellipse->setIconSize( QSize( 34, 34 ) );
     toolButton_camera_view_ellipse->setIcon( QIcon( ":/pictures/camera/window-ellipse-off.png" ) );
-    connect( toolButton_camera_view_ellipse, SIGNAL( clicked( bool ) ), this, SLOT( slot_toolButtonEllipseClicked( bool ) ) );
+    connect( toolButton_camera_view_ellipse, SIGNAL( clicked(bool) ), this, SLOT( slot_toolButtonEllipseClicked(bool) ) );
 
     toolButton_camera_view_circle = new QToolButton;
     toolButton_camera_view_circle->setObjectName( "toolButton_camera_view_circle-" + QString::number( counter ) );
@@ -141,7 +158,7 @@ QvkCameraSingle::QvkCameraSingle( Ui_formMainWindow *ui_surface, QCameraDevice m
     toolButton_camera_view_circle->setAutoRaise( true );
     toolButton_camera_view_circle->setIconSize( QSize( 34, 34 ) );
     toolButton_camera_view_circle->setIcon( QIcon( ":/pictures/camera/window-circle-off.png" ) );
-    connect( toolButton_camera_view_circle, SIGNAL( clicked( bool ) ), this, SLOT( slot_toolButtonCircleClicked( bool ) ) );
+    connect( toolButton_camera_view_circle, SIGNAL( clicked(bool) ), this, SLOT( slot_toolButtonCircleClicked(bool) ) );
 
     // Widget zur aufnahme der Toolbutton Rectangle, Ellipse und Circle
     widgetToolButton = new QWidget;
@@ -194,46 +211,46 @@ QvkCameraSingle::QvkCameraSingle( Ui_formMainWindow *ui_surface, QCameraDevice m
 
     vkCameraWindow = new QvkCameraWindow( ui, checkBoxCameraWindowFrame );
     vkCameraWindow->setObjectName( "vkCameraWindow-" + QString::number( counter ));
-    connect( vkCameraWindow, SIGNAL( signal_cameraWindow_close( bool ) ), checkBoxCameraOnOff, SLOT( click() ) );
-    connect( checkBoxCameraWindowFrame, SIGNAL( clicked( bool ) ), this, SLOT( slot_cameraWindowFrameOnOff( bool ) ) );
+    connect( vkCameraWindow, SIGNAL( signal_cameraWindow_close(bool) ), checkBoxCameraOnOff, SLOT(click()) );
+    connect( checkBoxCameraWindowFrame, SIGNAL( clicked(bool) ), this, SLOT( slot_cameraWindowFrameOnOff(bool) ) );
 
     vkCameraSettingsDialog = new cameraSettingsDialog;
-    connect( sliderCameraWindowSize, SIGNAL( rangeChanged( int, int ) ), vkCameraSettingsDialog->dialog_sliderCameraWindowSize, SLOT( setRange( int, int ) ) );
-    connect( sliderCameraWindowSize, SIGNAL( valueChanged( int ) ),      vkCameraSettingsDialog->dialog_sliderCameraWindowSize, SLOT( setValue( int ) ) );
-    connect( sliderCameraWindowZoom, SIGNAL( rangeChanged( int, int ) ), vkCameraSettingsDialog->dialog_sliderCameraWindowZoom, SLOT( setRange( int, int ) ) );
-    connect( sliderCameraWindowZoom, SIGNAL( valueChanged( int ) ),      vkCameraSettingsDialog->dialog_sliderCameraWindowZoom, SLOT( setValue( int ) ) );
-    connect( vkCameraSettingsDialog->dialog_sliderCameraWindowSize, SIGNAL( valueChanged( int ) ), sliderCameraWindowSize, SLOT( setValue( int ) ) );
-    connect( vkCameraSettingsDialog->dialog_sliderCameraWindowZoom, SIGNAL( valueChanged( int ) ), sliderCameraWindowZoom, SLOT( setValue( int ) ) );
+    connect( sliderCameraWindowSize, SIGNAL( rangeChanged(int,int) ), vkCameraSettingsDialog->dialog_sliderCameraWindowSize, SLOT( setRange(int,int) ) );
+    connect( sliderCameraWindowSize, SIGNAL( valueChanged(int) ),      vkCameraSettingsDialog->dialog_sliderCameraWindowSize, SLOT( setValue(int) ) );
+    connect( sliderCameraWindowZoom, SIGNAL( rangeChanged(int,int) ), vkCameraSettingsDialog->dialog_sliderCameraWindowZoom, SLOT( setRange(int,int) ) );
+    connect( sliderCameraWindowZoom, SIGNAL( valueChanged(int) ),      vkCameraSettingsDialog->dialog_sliderCameraWindowZoom, SLOT( setValue(int) ) );
+    connect( vkCameraSettingsDialog->dialog_sliderCameraWindowSize, SIGNAL( valueChanged(int) ), sliderCameraWindowSize, SLOT( setValue(int) ) );
+    connect( vkCameraSettingsDialog->dialog_sliderCameraWindowZoom, SIGNAL( valueChanged(int) ), sliderCameraWindowZoom, SLOT( setValue(int) ) );
 
-    connect( checkBoxCameraMirrorHorizontal, SIGNAL( toggled( bool ) ), vkCameraSettingsDialog->ui->checkBoxCameraMirrorHorizontal, SLOT( setChecked( bool ) ) );
-    connect( checkBoxCameraMirrorVertical,   SIGNAL( toggled( bool ) ), vkCameraSettingsDialog->ui->checkBoxCameraMirrorVertical,   SLOT( setChecked( bool ) ) );
-    connect( checkBoxCameraInvert,           SIGNAL( toggled( bool ) ), vkCameraSettingsDialog->ui->checkBoxCameraInvert,           SLOT( setChecked( bool ) ) );
-    connect( checkBoxCameraGray,             SIGNAL( toggled( bool ) ), vkCameraSettingsDialog->ui->checkBoxCameraGray,             SLOT( setChecked( bool ) ) );
-    connect( checkBoxCameraMono,             SIGNAL( toggled( bool ) ), vkCameraSettingsDialog->ui->checkBoxCameraMono,             SLOT( setChecked( bool ) ) );
-    connect( checkBoxCameraWindowFrame,      SIGNAL( toggled( bool ) ), vkCameraSettingsDialog->ui->checkBoxCameraWindowFrame,      SLOT( setChecked( bool ) ) );
-    connect( toolButton_camera_view_rectangle, SIGNAL( clicked( bool ) ), vkCameraSettingsDialog->ui->toolButton_camera_view_rectangle, SLOT( setChecked( bool )) );
-    connect( toolButton_camera_view_ellipse,   SIGNAL( clicked( bool ) ), vkCameraSettingsDialog->ui->toolButton_camera_view_ellipse,   SLOT( setChecked( bool ) ) );
-    connect( toolButton_camera_view_circle,    SIGNAL( clicked( bool ) ), vkCameraSettingsDialog->ui->toolButton_camera_view_circle,    SLOT( setChecked( bool ) ) );
+    connect( checkBoxCameraMirrorHorizontal, SIGNAL( toggled(bool) ), vkCameraSettingsDialog->ui->checkBoxCameraMirrorHorizontal, SLOT( setChecked(bool) ) );
+    connect( checkBoxCameraMirrorVertical,   SIGNAL( toggled(bool) ), vkCameraSettingsDialog->ui->checkBoxCameraMirrorVertical,   SLOT( setChecked(bool) ) );
+    connect( checkBoxCameraInvert,           SIGNAL( toggled(bool) ), vkCameraSettingsDialog->ui->checkBoxCameraInvert,           SLOT( setChecked(bool) ) );
+    connect( checkBoxCameraGray,             SIGNAL( toggled(bool) ), vkCameraSettingsDialog->ui->checkBoxCameraGray,             SLOT( setChecked(bool) ) );
+    connect( checkBoxCameraMono,             SIGNAL( toggled(bool) ), vkCameraSettingsDialog->ui->checkBoxCameraMono,             SLOT( setChecked(bool) ) );
+    connect( checkBoxCameraWindowFrame,      SIGNAL( toggled(bool) ), vkCameraSettingsDialog->ui->checkBoxCameraWindowFrame,      SLOT( setChecked(bool) ) );
+    connect( toolButton_camera_view_rectangle, SIGNAL( clicked(bool) ), vkCameraSettingsDialog->ui->toolButton_camera_view_rectangle, SLOT( setChecked(bool) ) );
+    connect( toolButton_camera_view_ellipse,   SIGNAL( clicked(bool) ), vkCameraSettingsDialog->ui->toolButton_camera_view_ellipse,   SLOT( setChecked(bool) ) );
+    connect( toolButton_camera_view_circle,    SIGNAL( clicked(bool) ), vkCameraSettingsDialog->ui->toolButton_camera_view_circle,    SLOT( setChecked(bool) ) );
 
-    connect( vkCameraSettingsDialog->ui->checkBoxCameraMirrorHorizontal, SIGNAL( toggled( bool ) ), checkBoxCameraMirrorHorizontal, SLOT( setChecked( bool ) ) );
-    connect( vkCameraSettingsDialog->ui->checkBoxCameraMirrorVertical,   SIGNAL( toggled( bool ) ), checkBoxCameraMirrorVertical,   SLOT( setChecked( bool ) ) );
-    connect( vkCameraSettingsDialog->ui->checkBoxCameraInvert,           SIGNAL( toggled( bool ) ), checkBoxCameraInvert,           SLOT( setChecked( bool ) ) );
-    connect( vkCameraSettingsDialog->ui->checkBoxCameraGray,             SIGNAL( toggled( bool ) ), checkBoxCameraGray,             SLOT( setChecked( bool ) ) );
-    connect( vkCameraSettingsDialog->ui->checkBoxCameraMono,             SIGNAL( toggled( bool ) ), checkBoxCameraMono,             SLOT( setChecked( bool ) ) );
-    connect( vkCameraSettingsDialog->ui->checkBoxCameraWindowFrame,      SIGNAL( toggled( bool ) ), checkBoxCameraWindowFrame,      SLOT( setChecked( bool ) ) );
-    connect( vkCameraSettingsDialog->ui->comboBoxCameraResolution,  SIGNAL( currentIndexChanged( int ) ), comboBoxCameraResolution, SLOT( setCurrentIndex( int ) ) );
-    connect( vkCameraSettingsDialog->ui->toolButton_camera_view_rectangle, SIGNAL( clicked( bool ) ), toolButton_camera_view_rectangle, SLOT( setChecked( bool ) ) );
-    connect( vkCameraSettingsDialog->ui->toolButton_camera_view_ellipse,   SIGNAL( clicked( bool ) ), toolButton_camera_view_ellipse,   SLOT( setChecked( bool ) ) );
-    connect( vkCameraSettingsDialog->ui->toolButton_camera_view_circle,    SIGNAL( clicked( bool ) ), toolButton_camera_view_circle,    SLOT( setChecked( bool ) ) );
+    connect( vkCameraSettingsDialog->ui->checkBoxCameraMirrorHorizontal, SIGNAL( toggled(bool) ), checkBoxCameraMirrorHorizontal, SLOT( setChecked(bool) ) );
+    connect( vkCameraSettingsDialog->ui->checkBoxCameraMirrorVertical,   SIGNAL( toggled(bool) ), checkBoxCameraMirrorVertical,   SLOT( setChecked(bool) ) );
+    connect( vkCameraSettingsDialog->ui->checkBoxCameraInvert,           SIGNAL( toggled(bool) ), checkBoxCameraInvert,           SLOT( setChecked(bool) ) );
+    connect( vkCameraSettingsDialog->ui->checkBoxCameraGray,             SIGNAL( toggled(bool) ), checkBoxCameraGray,             SLOT( setChecked(bool) ) );
+    connect( vkCameraSettingsDialog->ui->checkBoxCameraMono,             SIGNAL( toggled(bool) ), checkBoxCameraMono,             SLOT( setChecked(bool) ) );
+    connect( vkCameraSettingsDialog->ui->checkBoxCameraWindowFrame,      SIGNAL( toggled(bool) ), checkBoxCameraWindowFrame,      SLOT( setChecked(bool) ) );
+    connect( vkCameraSettingsDialog->ui->comboBoxCameraResolution,  SIGNAL( currentIndexChanged(int) ), comboBoxCameraResolution, SLOT( setCurrentIndex(int) ) );
+    connect( vkCameraSettingsDialog->ui->toolButton_camera_view_rectangle, SIGNAL( clicked(bool) ), toolButton_camera_view_rectangle, SLOT( setChecked(bool) ) );
+    connect( vkCameraSettingsDialog->ui->toolButton_camera_view_ellipse,   SIGNAL( clicked(bool) ), toolButton_camera_view_ellipse,   SLOT( setChecked(bool) ) );
+    connect( vkCameraSettingsDialog->ui->toolButton_camera_view_circle,    SIGNAL( clicked(bool) ), toolButton_camera_view_circle,    SLOT( setChecked(bool) ) );
     connect( vkCameraSettingsDialog->ui->buttonBox,                       SIGNAL( accepted() ),       vkCameraSettingsDialog,           SLOT( close() ) );
-    connect( vkCameraSettingsDialog->ui->pushButtonSwitchToFullscreen,    SIGNAL( clicked( bool ) ),  this,                             SLOT( slot_switchToFullscreen() ) );
-    connect( vkCameraSettingsDialog->ui->comboBoxCameraVideoFormat,       SIGNAL( currentIndexChanged( int ) ), comboBoxCameraVideoFormat, SLOT( setCurrentIndex( int ) ) );
+    connect( vkCameraSettingsDialog->ui->pushButtonSwitchToFullscreen,    SIGNAL( clicked(bool) ),  this,                             SLOT( slot_switchToFullscreen() ) );
+    connect( vkCameraSettingsDialog->ui->comboBoxCameraVideoFormat,       SIGNAL( currentIndexChanged(int) ), comboBoxCameraVideoFormat, SLOT( setCurrentIndex(int) ) );
 
-    connect( comboBoxCameraVideoFormat, SIGNAL( currentIndexChanged( int ) ), vkCameraSettingsDialog->ui->comboBoxCameraVideoFormat, SLOT( setCurrentIndex( int ) ) );
+    connect( comboBoxCameraVideoFormat, SIGNAL( currentIndexChanged(int) ), vkCameraSettingsDialog->ui->comboBoxCameraVideoFormat, SLOT( setCurrentIndex(int) ) );
 
-    connect( vkCameraWindow, SIGNAL( signal_mousePressEvent( QMouseEvent* ) ),        this,                  SLOT( slot_vkCameraSettingsDialogShow()) );
-    connect( vkCameraWindow, SIGNAL( signal_changelabelCameraWindowSize( QString ) ), labelCameraWindowSize, SLOT( setText( QString) ) );
-    connect( vkCameraWindow, SIGNAL( signal_changelabelCameraWindowSize( QString ) ), vkCameraSettingsDialog->ui->labelCameraWindowSize, SLOT( setText( QString) ) );
+    connect( vkCameraWindow, SIGNAL( signal_mousePressEvent(QMouseEvent*) ),        this,                  SLOT( slot_vkCameraSettingsDialogShow() ) );
+    connect( vkCameraWindow, SIGNAL( signal_changelabelCameraWindowSize(QString) ), labelCameraWindowSize, SLOT( setText(QString) ) );
+    connect( vkCameraWindow, SIGNAL( signal_changelabelCameraWindowSize(QString) ), vkCameraSettingsDialog->ui->labelCameraWindowSize, SLOT( setText(QString) ) );
 
     for ( int i = 0; i < cameraDevice.videoFormats().count(); i++ ) {
         QString format = QVideoFrameFormat::pixelFormatToString( cameraDevice.videoFormats().at(i).pixelFormat() ).toUpper();
@@ -253,6 +270,16 @@ QvkCameraSingle::~QvkCameraSingle()
 }
 
 
+void QvkCameraSingle::slot_pushButtonShortcut( bool value )
+{
+    if ( value == true ) {
+        pushButtonShortcut->setIcon( QIcon( ":/pictures/screencast/accept.png" ) );
+    } else {
+        pushButtonShortcut->setIcon( QIcon( ":/pictures/screencast/missing.png" ) );
+    }
+}
+
+
 void QvkCameraSingle::slot_cameraWindowFrameOnOff( bool value )
 {
 #ifdef Q_OS_UNIX
@@ -386,8 +413,8 @@ void QvkCameraSingle::slot_comboboxCameraResolutionsInsertValues( int value )
     vkCameraSettingsDialog->dialog_sliderCameraWindowSize->setMaximum( comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() - 100 );
     vkCameraSettingsDialog->dialog_sliderCameraWindowZoom->setMaximum( comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() / 2 );
 
-    connect( comboBoxCameraResolution, SIGNAL( currentIndexChanged( int ) ), this, SLOT( slot_comboboxCameraResolutionsCurrentIndexChanged( int ) ) );
-    connect( comboBoxCameraResolution,  SIGNAL( currentIndexChanged( int ) ), vkCameraSettingsDialog->ui->comboBoxCameraResolution,  SLOT( setCurrentIndex( int ) ) );
+    connect( comboBoxCameraResolution, SIGNAL( currentIndexChanged(int) ), this, SLOT( slot_comboboxCameraResolutionsCurrentIndexChanged(int) ) );
+    connect( comboBoxCameraResolution,  SIGNAL( currentIndexChanged(int) ), vkCameraSettingsDialog->ui->comboBoxCameraResolution,  SLOT( setCurrentIndex(int) ) );
 }
 
 
@@ -486,15 +513,17 @@ void QvkCameraSingle::slot_radioButtonCurrentCameraClicked( bool value )
     // Set text from current camera
     QList<QLabel *> listLabel = ui->centralWidget->findChildren<QLabel *>( "labelCurrentCamera" );
     if ( radioButtonCamera->isChecked() == true ) {
-        listLabel.at(0)->setText( checkBoxCameraOnOff->text() );
+        QLabel *label = listLabel.at(0);
+        label->setText( checkBoxCameraOnOff->text().remove( "&" ) );
     }
 
      // Hide widgetToolButton from other camera
     QList<QWidget *> listWidget = ui->centralWidget->findChildren<QWidget *>();
     if ( listWidget.empty() == false ) {
         for ( int i = 0; i < listWidget.count(); i++ ) {
-            if ( listWidget.at(i)->objectName().contains( "widgetToolButton-" ) ) {
-                listWidget.at(i)->hide();
+            QWidget *widget = listWidget.at(i);
+            if ( widget->objectName().contains( "widgetToolButton-" ) ) {
+                widget->hide();
             }
         }
     }
@@ -503,23 +532,24 @@ void QvkCameraSingle::slot_radioButtonCurrentCameraClicked( bool value )
     QList<QCheckBox *> listCheckBox = ui->centralWidget->findChildren<QCheckBox *>();
     if ( listCheckBox.empty() == false ) {
         for ( int i = 0; i < listCheckBox.count(); i++ ) {
-            if ( listCheckBox.at(i)->objectName().contains( "checkBoxCameraWindowFrame" ) ) {
-                listCheckBox.at(i)->hide();
+            QCheckBox *checkBox = listCheckBox.at(i);
+            if ( checkBox->objectName().contains( "checkBoxCameraWindowFrame" ) ) {
+                checkBox->hide();
             }
-            if ( listCheckBox.at(i)->objectName().contains( "checkBoxCameraMirrorVertical" ) ) {
-                listCheckBox.at(i)->hide();
+            if ( checkBox->objectName().contains( "checkBoxCameraMirrorVertical" ) ) {
+                checkBox->hide();
             }
-            if ( listCheckBox.at(i)->objectName().contains( "checkBoxCameraMirrorHorizontal" ) ) {
-                listCheckBox.at(i)->hide();
+            if ( checkBox->objectName().contains( "checkBoxCameraMirrorHorizontal" ) ) {
+                checkBox->hide();
             }
-            if ( listCheckBox.at(i)->objectName().contains( "checkBoxCameraInvert" ) ) {
-                listCheckBox.at(i)->hide();
+            if ( checkBox->objectName().contains( "checkBoxCameraInvert" ) ) {
+                checkBox->hide();
             }
-            if ( listCheckBox.at(i)->objectName().contains( "checkBoxCameraGray" ) ) {
-                listCheckBox.at(i)->hide();
+            if ( checkBox->objectName().contains( "checkBoxCameraGray" ) ) {
+                checkBox->hide();
             }
-            if ( listCheckBox.at(i)->objectName().contains( "checkBoxCameraMono" ) ) {
-                listCheckBox.at(i)->hide();
+            if ( checkBox->objectName().contains( "checkBoxCameraMono" ) ) {
+                checkBox->hide();
             }
         }
     }
@@ -528,11 +558,12 @@ void QvkCameraSingle::slot_radioButtonCurrentCameraClicked( bool value )
     QList<QvkSpezialSlider *> listSpezialSlider = ui->centralWidget->findChildren<QvkSpezialSlider *>();
     if ( listSpezialSlider.empty() == false ) {
         for ( int i = 0; i < listSpezialSlider.count(); i++ ) {
-            if ( listSpezialSlider.at(i)->objectName().contains( "sliderCameraWindowSize" ) ) {
-                listSpezialSlider.at(i)->hide();
+            QvkSpezialSlider *vkSpezialSlider = listSpezialSlider.at(i);
+            if ( vkSpezialSlider->objectName().contains( "sliderCameraWindowSize" ) ) {
+                vkSpezialSlider->hide();
             }
-            if ( listSpezialSlider.at(i)->objectName().contains( "sliderCameraWindowZoom" ) ) {
-                listSpezialSlider.at(i)->hide();
+            if ( vkSpezialSlider->objectName().contains( "sliderCameraWindowZoom" ) ) {
+                vkSpezialSlider->hide();
             }
         }
     }
@@ -540,8 +571,9 @@ void QvkCameraSingle::slot_radioButtonCurrentCameraClicked( bool value )
     QList<QLabel *> listLabelCameraWindowSize = ui->centralWidget->findChildren<QLabel *>();
     if ( listLabelCameraWindowSize.empty() == false ) {
         for ( int i = 0; i < listLabelCameraWindowSize.count(); i++ ) {
-            if ( listLabelCameraWindowSize.at(i)->objectName().contains( "labelCameraWindowSize" ) ) {
-                listLabelCameraWindowSize.at(i)->hide();
+            QLabel *label = listLabelCameraWindowSize.at(i);
+            if ( label->objectName().contains( "labelCameraWindowSize" ) ) {
+                label->hide();
             }
         }
     }
@@ -575,7 +607,7 @@ void QvkCameraSingle::slot_videoFrameChanged( QVideoFrame videoFrame )
         image = image.mirrored( true, false );
     }
 
-    if ( checkBoxCameraMirrorVertical->isChecked() == false ) {
+    if ( checkBoxCameraMirrorVertical->isChecked() == true ) {
         image = image.mirrored( false, true );
     }
 
