@@ -22,12 +22,18 @@
 
 #include "global.h"
 #include <QString>
+#include <QLineEdit>
 
 namespace global
 {
-    QString version = "4.1.0";
+    QString version = "4.7.0";
     QString name = "vokoscreenNG";
     QString nameOutput = "[" + name + "]";
     int showclickCounter = 0;
-    bool testWASAPI = false;
+    QLineEdit *lineEditWASAPIWatcher;
+    QList<QLineEdit*> *listChildren;
+    QLineEdit *lineEditConvertMP4;
+    QLineEdit *lineEditConvertGIF;
+    QLineEdit *lineEditConvertWEBM;
+    QLineEdit *lineEditConvertRepair;
 }
