@@ -29,5 +29,10 @@ namespace global
     extern QString nameOutput;
     extern QString version;
     extern int showclickCounter;
-    extern bool testWASAPI;
+    extern QLineEdit *lineEditWASAPIWatcher;
+    extern QList<QLineEdit*> *listChildren;
+    extern QLineEdit *lineEditConvertMP4;
+    extern QLineEdit *lineEditConvertGIF;
+    extern QLineEdit *lineEditConvertWEBM;
+    extern QLineEdit *lineEditConvertRepair;
 }
